==> apache-nuttx-apps-12.5.1.tar.gz: apps/testing/testsuites/kernel/time/cmocka_time_test.c <==
/****************************************************************************
 * apps/testing/testsuites/kernel/time/cmocka_time_test.c
 * Copyright (C) 2020 Xiaomi Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>
#include <stdint.h>
#include <stdarg.h>
#include <stddef.h>
#include <setjmp.h>
#include <stdio.h>
#include "TimeTest.h"
#include <cmocka.h>

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: cmocka_time_test_main
 ****************************************************************************/

int main(int argc, char *argv[])
{
  /* Add Test Cases */

  const struct CMUnitTest nuttx_time_testsuites[] = {
      cmocka_unit_test(test_nuttx_clock_test_smoke01),
      cmocka_unit_test(test_nuttx_clock_test_timer01),
      cmocka_unit_test(test_nuttx_clock_test_timer03),
      cmocka_unit_test(test_nuttx_clock_test_timer04),
      cmocka_unit_test(test_nuttx_clock_test_timer05),
      cmocka_unit_test(test_nuttx_clock_test_clock01),
      cmocka_unit_test(test_nuttx_clock_test_clock02),
  };

  /* Run Test cases */

  cmocka_run_group_tests(nuttx_time_testsuites, NULL, NULL);
  return 0;
}

==> apache-nuttx-apps-12.11.0.tar.gz: apps/testing/testsuites/kernel/time/cmocka_time_test.c <==
/****************************************************************************
 * apps/testing/testsuites/kernel/time/cmocka_time_test.c
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/
#include <nuttx/config.h>
#include <stdint.h>
#include <stdarg.h>
#include <stddef.h>
#include <setjmp.h>
#include <stdio.h>
#include "TimeTest.h"
#include <cmocka.h>

/****************************************************************************
 * Name: cmocka_time_test_main
 ****************************************************************************/

/****************************************************************************
 * Private Functions
 ****************************************************************************/

int main(int argc, char *argv[])
{
  /* Add Test Cases */

  const struct CMUnitTest nuttx_time_test_suites[] =
  {
      cmocka_unit_test(test_nuttx_clock_test_smoke01),
      cmocka_unit_test(test_nuttx_clock_test_timer01),
      cmocka_unit_test(test_nuttx_clock_test_timer03),
      cmocka_unit_test(test_nuttx_clock_test_timer04),
      cmocka_unit_test(test_nuttx_clock_test_timer05),
      cmocka_unit_test(test_nuttx_clock_test_clock01),
      cmocka_unit_test(test_nuttx_clock_test_clock02),
  };

  /* Run Test cases */

  cmocka_run_group_tests(nuttx_time_test_suites, NULL, NULL);
  return 0;
}
